@@ -44,11 +44,11 @@ sub import {
     return;
 }
 
-die "Perl lib version (5.10.1) doesn't match executable version ($])"
+die "Perl lib version (5.12.4) doesn't match executable version ($])"
     unless $^V;
 
-$^V eq 5.10.1
-    or die "Perl lib version (5.10.1) doesn't match executable version (" .
+$^V eq 5.12.4
+    or die "Perl lib version (5.12.4) doesn't match executable version (" .
 	sprintf("v%vd",$^V) . ")";
 
 sub FETCH {
@@ -73,7 +73,7 @@ sub AUTOLOAD {
 
 # tie returns the object, so the value returned to require will be true.
 tie %Config, 'Config', {
-    archlibexp => '/usr/lib/perl/5.10',
+    archlibexp => '/usr/lib/perl/5.12',
     archname => 'x86_64-linux-gnu-thread-multi',
     cc => 'cc',
     d_readlink => 'define',
@@ -81,18 +81,18 @@ tie %Config, 'Config', {
     dlsrc => 'dl_dlopen.xs',
     dont_use_nlink => undef,
     exe_ext => '',
-    inc_version_list => '5.10.0',
+    inc_version_list => '5.12.3',
     intsize => '4',
     ldlibpthname => 'LD_LIBRARY_PATH',
-    libpth => '/usr/local/lib /lib /usr/lib /lib64 /usr/lib64',
+    libpth => '/usr/local/lib /lib/x86_64-linux-gnu /lib/../lib /usr/lib/x86_64-linux-gnu /usr/lib/../lib /lib /usr/lib',
     osname => 'linux',
-    osvers => '2.6.24-28-server',
+    osvers => '2.6.42-37-generic',
     path_sep => ':',
-    privlibexp => '/usr/share/perl/5.10',
+    privlibexp => '/usr/share/perl/5.12',
     scriptdir => '/usr/bin',
-    sitearchexp => '/usr/local/lib/perl/5.10.1',
-    sitelibexp => '/usr/local/share/perl/5.10.1',
+    sitearchexp => '/usr/local/lib/perl/5.12.4',
+    sitelibexp => '/usr/local/share/perl/5.12.4',
     useithreads => 'define',
     usevendorprefix => 'define',
-    version => '5.10.1',
+    version => '5.12.4',
 };
