@@ -6,7 +6,7 @@ from distutils import log
 
 # This module should be kept compatible with Python 2.1.
 
-__revision__ = "$Id: install.py 62788 2008-05-06 22:41:46Z christian.heimes $"
+__revision__ = "$Id$"
 
 import sys, os, string
 from types import *
@@ -83,20 +83,6 @@ INSTALL_SCHEMES = {
         'scripts': '$userbase/Scripts',
         'data'   : '$userbase',
         },
-    'mac': {
-        'purelib': '$base/Lib/site-packages',
-        'platlib': '$base/Lib/site-packages',
-        'headers': '$base/Include/$dist_name',
-        'scripts': '$base/Scripts',
-        'data'   : '$base',
-        },
-    'mac_user': {
-        'purelib': '$usersite',
-        'platlib': '$usersite',
-        'headers': '$userbase/$py_version_short/include/$dist_name',
-        'scripts': '$userbase/bin',
-        'data'   : '$userbase',
-        },
     'os2': {
         'purelib': '$base/Lib/site-packages',
         'platlib': '$base/Lib/site-packages',
@@ -474,7 +460,7 @@ class install (Command):
             if self.install_layout:
                 if self.install_layout.lower() in ['deb']:
                     self.select_scheme("deb_system")
-                elif self.install_layout.lower() in ['unix']:
+                elif self.install_layout.lower() in ['posix', 'unix']:
                     self.select_scheme("unix_prefix")
                 else:
                     raise DistutilsOptionError(
@@ -485,9 +471,9 @@ class install (Command):
                 self.select_scheme("unix_prefix")
             else:
                 if os.path.normpath(self.prefix) == '/usr/local':
-                    self.prefix = self.exec_prefix = '/usr'
-                    self.install_base = self.install_platbase = '/usr'
-                self.select_scheme("unix_local")
+                    self.select_scheme("deb_system")
+                else:
+                    self.select_scheme("unix_local")
 
     # finalize_unix ()
 
